#@IgnoreInspection AddShebang

export ZCFG=$HOME/.config/zsh-config

# If not running interactively, don't do anything
case $- in
    *i*) ;;
      *) return;;
esac

########################
# ******************** #
# *                  * #
# *     COMPLETION   * #
# *                  * #
# ******************** #
########################

# enable bash completion in interactive shells
if [ -f /etc/bash_completion ]; then
    . /etc/bash_completion
fi

# if the command-not-found package is installed, use it
if [ -x /usr/lib/command-not-found ]; then
        function command_not_found_handle {
                # check because c-n-f could've been removed in the meantime
                if [ -x /usr/lib/command-not-found ]; then
                   /usr/bin/python /usr/lib/command-not-found -- $1
                   return $?
                else
                   return 127
                fi
        }
fi

########################
# ******************** #
# *                  * #
# *      HISTORY     * #
# *                  * #
# ******************** #
########################

# Eternal bash history.
# ---------------------
export HISTFILESIZE=
export HISTSIZE=
export HISTTIMEFORMAT="[%F %T] "
# Change the file location
export HISTFILE=~/.config/new_bash_history
# Force prompt to write history after every command
PROMPT_COMMAND="history -a; $PROMPT_COMMAND"

########################
# ******************** #
# *                  * #
# *       MISC       * #
# *                  * #
# ******************** #
########################

# check the window size after each command
shopt -s checkwinsize

# If set, the pattern "**" used in a pathname expansion context will
# match all files and zero or more directories and subdirectories.
#shopt -s globstar

# set variable identifying the chroot you work in (used in the prompt below)
if [ -z "${debian_chroot:-}" ] && [ -r /etc/debian_chroot ]; then
    debian_chroot=$(cat /etc/debian_chroot)
fi

# set a fancy prompt
case "$TERM" in
    xterm-color) color_prompt=yes;;
esac

# colored prompt
force_color_prompt=yes

if [ -n "$force_color_prompt" ]; then
    if [ -x /usr/bin/tput ] && tput setaf 1 >&/dev/null; then
        # We have color support; assume it's compliant with Ecma-48
        # (ISO/IEC-6429). (Lack of such support is extremely rare, and such
        # a case would tend to support setf rather than setaf.)
        color_prompt=yes
    else
        color_prompt=
    fi
fi

if [ "$color_prompt" = yes ]; then
    PS1='${debian_chroot:+($debian_chroot)}\[\033[01;32m\]\u@\h\[\033[00m\]:\[\033[01;34m\]\w\[\033[00m\]\$ '
else
    PS1='${debian_chroot:+($debian_chroot)}\u@\h:\w\$ '
fi
#unset color_prompt force_color_prompt

# enable color support of ls and also add handy aliases
if [ -x /usr/bin/dircolors ]; then
    test -r ~/.dircolors && eval "$(dircolors -b ~/.dircolors)" || eval "$(dircolors -b)"
    alias ls='ls --color=auto'
    alias dir='dir --color=auto'
    alias vdir='vdir --color=auto'

    alias grep='grep --color=auto'
    alias fgrep='fgrep --color=auto'
    alias egrep='egrep --color=auto'
fi

# Environment
if [ -f $ZCFG/dotfiles/environment.sh ]; then
    . $ZCFG/dotfiles/environment.sh
fi

# Alias definitions
if [ -f $ZCFG/dotfiles/bash_aliases.sh ]; then
    . $ZCFG/dotfiles/bash_aliases.sh
fi

# Start zsh if in OpenVZ CT
if [ -d /proc/vz ] && [ ! -d /proc/vz/beancounter ]; then
	cd && zsh && exit
fi
