#!/usr/bin/env bash

# ** Initiate with: **
# cd && wget http://git.str8.biz/mj/zsh-config/raw/master/tools/sys_base_install.sh -O | sh
# -------------------------------------------------------------------------------------------

set -e

export GJ_DEVENV="local_aptproxy"
export GJ_SHELL="bash"

# ** Helper Functions **
# ----------------------

function set_apt_proxy {
	if [[ "$GJ_DEVENV" == "local_aptproxy" ]]; then
		echo "Setting apt-proxy: srvths"
		printf 'Acquire::http { Proxy "http://192.168.188.110:3142"; };\nAcquire::https { Proxy "https://"; };\n' > /etc/apt/apt.conf.d/02proxy
	elif [[ "$GJ_DEVENV" == "hetzner_server" ]]; then
		echo "Setting apt-mirror: hetzner mirror"
		echo 'deb ftp://mirror.hetzner.de/debian/packages wheezy main contrib non-free' > /etc/apt/sources.list.d/hetzner.list
		echo 'deb ftp://mirror.hetzner.de/debian/security wheezy/updates main contrib non-free' >> /etc/apt/sources.list.d/hetzner.list
	fi
}

function get_shell_config {
	apt-get -yq install apt-utils curl git nano zsh
	mkdir ~/.config
	echo "cloning zsh config.."
	hash git >/dev/null 2>&1 && env git clone --depth=1 http://git.str8.biz/mj/zsh-config.git $ZCNF
}

set_apt_proxy

set -e

if [ ! -n "$ZCNF" ]; then
  ZCNF=~/.config/zsh-config
fi

if [ ! -n "$ZSH" ]; then
  ZSH=$ZCNF/repos/oh-my-zsh
fi

#export DEBIAN_FRONTEND=noninteractive

apt-get update

if [ "$GJ_SHELL" != "zsh" ]; then
	get_shell_config
fi

apt-get -yq upgrade && apt-get -yq dist-upgrade
apt-get -yq install locales-all localepurge makepasswd python-setuptools
apt-get -yq autoremove && apt-get -yq clean

dpkg-reconfigure localepurge
dpkg-reconfigure tzdata

easy_install pip
pip install autoenv
mkdir .autoenv && ln -s /usr/local/bin/activate.sh .autoenv/activate.sh

echo "\033[0;34mLooking for an existing zsh config...\033[0m"
if [ -f ~/.zshrc ] || [ -h ~/.zshrc ]; then
  echo "\033[0;33mFound ~/.zshrc.\033[0m \033[0;32mBacking up to ~/.zshrc.pre-zsh-cnf\033[0m";
  mv ~/.zshrc ~/.zshrc.pre-zsh-cnf;
fi

echo "\033[0;34mUsing the Zsh Config template file and adding it to ~/.zshrc\033[0m"
ln -s $ZCNF/templates/zshrc ~/.zshrc
ln -s $ZCNF/templates/bash_aliases ~/.bash_aliases
sed -i -e "/^export ZSH=/ c\\
export ZSH=$ZSH
" ~/.zshrc

echo "\033[0;34mCopying your current PATH and adding it to the end of ~/.zshrc for you.\033[0m"
sed -i -e "/export PATH=/ c\\
export PATH=\"$PATH\"
" ~/.zshrc

if [ "$SHELL" != "$(which zsh)" ]; then
    echo "\033[0;34mTime to change your default shell to zsh!\033[0m"
    chsh -s `which zsh`
fi

echo "\033[0;32m"'         __                                     __   '"\033[0m"
echo "\033[0;32m"'  ____  / /_     ____ ___  __  __   ____  _____/ /_  '"\033[0m"
echo "\033[0;32m"' / __ \/ __ \   / __ `__ \/ / / /  /_  / / ___/ __ \ '"\033[0m"
echo "\033[0;32m"'/ /_/ / / / /  / / / / / / /_/ /    / /_(__  ) / / / '"\033[0m"
echo "\033[0;32m"'\____/_/ /_/  /_/ /_/ /_/\__, /    /___/____/_/ /_/  '"\033[0m"
echo "\033[0;32m"'                        /____/                       ....is now installed!'"\033[0m"
echo "\n\n \033[0;32mPlease look over the ~/.zshrc file to select plugins, themes, and options.\033[0m"
echo "\n\n \033[0;32mp.s. Follow us at http://twitter.com/ohmyzsh.\033[0m"
echo "\n\n \033[0;32mp.p.s. Get stickers and t-shirts at http://shop.planetargon.com.\033[0m"
env zsh
. ~/.zshrc
